% =================================================================================
%
% argo_file_read          reads some of the variables contained in an
%                         ARGO format (profile) file (netcdf). See
%                         reference:
%                         "Argo User's manual" available on
%                         http://www.coriolis.eu.org/coriolis/cdc/argo_rfc.htm
%
% AUTHOR:                Emmanuelle Autret
%
% HISTORIC:              23/10/2003 - EA - version 1.00 - 
%                        with matlab version 6.13
%			 30/08/2004 -TL - version 1.01 -
%			 update for argo format version 2.01

% REQUIRES:              netcdf matlab toolbox
%
% EXAMPLE:               file_name='6900162_500621518.nc';
%
%                        [latitude,longitude,juld,pressure,temperature,salinity,platform_number,cycle_number,data_type,format_version,project_name,pi_name,direction,data_centre,data_state_indicator,data_mode,dc_reference,inst_reference,wmo_inst_type]=argo_file_read(file_name);
%
%
% SEE ALSO:              plot_latest_TS_profile.m, plot_contour.m.      
% 
% ================================================================================

function [latitude,longitude,juld,pressure,temperature,salinity,platform_number,cycle_number,data_type,format_version,project_name,pi_name,direction,data_centre,data_state_indicator,data_mode,dc_reference,inst_reference,wmo_inst_type]=argo_file_read(file_name);

latitude=[];
longitude=[];
juld=[];
pressure=[];
temperature=[];
salinity=[];
platform_number=[];
data_type=[];
format_version=[];
reference_date_time=[];
project_name=[];
pi_name=[];
cycle_number=[];
direction=[];
data_centre =[];
data_state_indicator=[];
data_mode=[];
dc_reference=[];
inst_reference=[];
wmo_inst_type=[];


ncstartup


f_cdf = netcdf(file_name,'read');


%Reads genaral informations
%============================

latitude   = f_cdf{'LATITUDE'}(:);
longitude   = f_cdf{'LONGITUDE'}(:);

reference_date_time = f_cdf{'REFERENCE_DATE_TIME'}(:);
dayref=datenum(sscanf(reference_date_time(1:4),'%f'),...
	    sscanf(reference_date_time(5:6),'%f'),sscanf(reference_date_time(7:8),'%f'),0,0,0);
juld = f_cdf{'JULD'}(:)+dayref;

data_type   = f_cdf{'DATA_TYPE'}(:);
format_version = f_cdf{'FORMAT_VERSION'}(:);
reference_date_time    = f_cdf{'REFERENCE_DATE_TIME'}(:);
project_name   = f_cdf{'PROJECT_NAME'}(:);
pi_name   = f_cdf{'PI_NAME'}(:);
platform_number  = f_cdf{'PLATFORM_NUMBER'}(:);
cycle_number  = f_cdf{'CYCLE_NUMBER'}(:);
direction  = f_cdf{'DIRECTION'}(:);
data_centre  = f_cdf{'DATA_CENTRE'}(:);
data_state_indicator  = f_cdf{'DATA_STATE_INDICATOR'}(:);
data_mode  = f_cdf{'DATA_MODE'}(:);
dc_reference  = f_cdf{'DC_REFERENCE'}(:);
inst_reference  = f_cdf{'INST_REFERENCE'}(:);
wmo_inst_type  = f_cdf{'WMO_INST_TYPE'}(:);



%Reads measurements
%======================

%PRESSURE
pressure = f_cdf{'PRES'}(:);
pres_fillvalue = f_cdf{'PRES'}.FillValue_(:);
pres_units=f_cdf{'PRES'}.units(:);
inok = find(pressure==pres_fillvalue);
if ~isempty(inok)
  pressure(inok)=NaN;
end
  
%TEMPERATURE
temperature = f_cdf{'TEMP'}(:);
temp_qc= f_cdf{'TEMP_QC'}(:);
temp_fillvalue = f_cdf{'TEMP'}.FillValue_(:);
temp_units=f_cdf{'TEMP'}.units(:);
inok = find(temperature==temp_fillvalue);
if ~isempty(inok)
  temperature(inok)=NaN;
end
%Selection of measurements with QC=1 or QC=2 or QC=5
inok =find(double(temp_qc)~= double('1') &...
	   double(temp_qc)~= double('2') & ...
	   double(temp_qc)~= double('5'));
if ~isempty(inok)
  temperature(inok)=NaN;
end

clear temp_qc 


%SALINITY
salinity = f_cdf{'PSAL'}(:);
if ~isempty(salinity)
  psal_qc  = f_cdf{'PSAL_QC'}(:);
  psal_fillvalue = f_cdf{'PSAL'}.FillValue_(:);
  psal_units = f_cdf{'PSAL'}.units(:);
  inok=find(salinity==psal_fillvalue);
  if ~isempty(inok)
    salinity(inok)=NaN;
  end
  inok =find(double(psal_qc)~= double('1') &...
	     double(psal_qc)~= double('2') & ...
	     double(psal_qc)~= double('5'));
  if ~isempty(inok)
    salinity(inok)=NaN;
  end
end

clear psal_qc 

close(f_cdf);



%if T not defined => P and S not defined
inok = find(~finite(temperature));
if ~isempty(inok)
  pressure(inok)=NaN;
  if ~isempty(salinity)
    salinity(inok)=NaN;
  end
end


iok=find(finite(temperature));
if isempty(iok)
  fprintf('%s\n',...
	  [' no validated (with QC=1 or QC=2 or QC=5) temperature measurements in this file']);
end

iok=find(finite(salinity));
if isempty(iok)
  fprintf('%s\n',...
	    [' no validated (existing or with QC=1 or QC=2 or QC=5) salinity measurements in this file ']);
end
